///<reference path="../.d.ts"/>
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var path = require("path");
var shell = require("shelljs");
var util = require("util");
var os = require("os");
var semver = require("semver");
var xcode = require("xcode");
var constants = require("../constants");
var helpers = require("../common/helpers");
var projectServiceBaseLib = require("./platform-project-service-base");
var IOSProjectService = (function (_super) {
    __extends(IOSProjectService, _super);
    function IOSProjectService($projectData, $fs, $childProcess, $errors, $logger, $iOSEmulatorServices, $options, $injector, $projectDataService, $prompter) {
        _super.call(this, $fs);
        this.$projectData = $projectData;
        this.$childProcess = $childProcess;
        this.$errors = $errors;
        this.$logger = $logger;
        this.$iOSEmulatorServices = $iOSEmulatorServices;
        this.$options = $options;
        this.$injector = $injector;
        this.$projectDataService = $projectDataService;
        this.$prompter = $prompter;
    }
    Object.defineProperty(IOSProjectService.prototype, "$npmInstallationManager", {
        get: function () {
            return this.$injector.resolve("npmInstallationManager");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IOSProjectService.prototype, "platformData", {
        get: function () {
            var projectRoot = path.join(this.$projectData.platformsDir, "ios");
            return {
                frameworkPackageName: "tns-ios",
                normalizedPlatformName: "iOS",
                appDestinationDirectoryPath: path.join(projectRoot, this.$projectData.projectName),
                platformProjectService: this,
                emulatorServices: this.$iOSEmulatorServices,
                projectRoot: projectRoot,
                deviceBuildOutputPath: path.join(projectRoot, "build", "device"),
                emulatorBuildOutputPath: path.join(projectRoot, "build", "emulator"),
                validPackageNamesForDevice: [
                    this.$projectData.projectName + ".ipa"
                ],
                validPackageNamesForEmulator: [
                    this.$projectData.projectName + ".app"
                ],
                frameworkFilesExtensions: [".a", ".framework", ".bin"],
                frameworkDirectoriesExtensions: [".framework"],
                frameworkDirectoriesNames: ["Metadata", "metadataGenerator"],
                targetedOS: ['darwin'],
                configurationFileName: "Info.plist",
                configurationFilePath: path.join(projectRoot, this.$projectData.projectName, this.$projectData.projectName + "-Info.plist"),
                mergeXmlConfig: [{ "nodename": "plist", "attrname": "*" }, { "nodename": "dict", "attrname": "*" }]
            };
        },
        enumerable: true,
        configurable: true
    });
    IOSProjectService.prototype.getAppResourcesDestinationDirectoryPath = function () {
        var _this = this;
        return (function () {
            _this.$projectDataService.initialize(_this.$projectData.projectDir);
            var frameworkVersion = _this.$projectDataService.getValue(_this.platformData.frameworkPackageName).wait()["version"];
            if (semver.lt(frameworkVersion, "1.3.0")) {
                return path.join(_this.platformData.projectRoot, _this.$projectData.projectName, "Resources", "icons");
            }
            return path.join(_this.platformData.projectRoot, _this.$projectData.projectName, "Resources");
        }).future()();
    };
    IOSProjectService.prototype.validate = function () {
        var _this = this;
        return (function () {
            try {
                _this.$childProcess.exec("which xcodebuild").wait();
            }
            catch (error) {
                _this.$errors.fail("Xcode is not installed. Make sure you have Xcode installed and added to your PATH");
            }
            var xcodeBuildVersion = _this.$childProcess.exec("xcodebuild -version | head -n 1 | sed -e 's/Xcode //'").wait();
            var splitedXcodeBuildVersion = xcodeBuildVersion.split(".");
            if (splitedXcodeBuildVersion.length === 3) {
                xcodeBuildVersion = util.format("%s.%s", splitedXcodeBuildVersion[0], splitedXcodeBuildVersion[1]);
            }
            if (helpers.versionCompare(xcodeBuildVersion, IOSProjectService.XCODEBUILD_MIN_VERSION) < 0) {
                _this.$errors.fail("NativeScript can only run in Xcode version %s or greater", IOSProjectService.XCODEBUILD_MIN_VERSION);
            }
        }).future()();
    };
    IOSProjectService.prototype.createProject = function (frameworkDir, frameworkVersion) {
        var _this = this;
        return (function () {
            _this.$fs.ensureDirectoryExists(path.join(_this.platformData.projectRoot, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER)).wait();
            if (_this.$options.symlink) {
                var xcodeProjectName = util.format("%s.xcodeproj", IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER);
                shell.cp("-R", path.join(frameworkDir, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER, "*"), path.join(_this.platformData.projectRoot, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER));
                shell.cp("-R", path.join(frameworkDir, xcodeProjectName), _this.platformData.projectRoot);
                var directoryContent = _this.$fs.readDirectory(frameworkDir).wait();
                var frameworkFiles = _.difference(directoryContent, [IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER, xcodeProjectName]);
                _.each(frameworkFiles, function (file) {
                    _this.$fs.symlink(path.join(frameworkDir, file), path.join(_this.platformData.projectRoot, file)).wait();
                });
            }
            else {
                shell.cp("-R", path.join(frameworkDir, "*"), _this.platformData.projectRoot);
            }
        }).future()();
    };
    IOSProjectService.prototype.interpolateData = function (projectRoot) {
        var _this = this;
        return (function () {
            var infoPlistFilePath = path.join(projectRoot, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER, util.format("%s-%s", IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER, "Info.plist"));
            shell.sed('-i', "__CFBUNDLEIDENTIFIER__", _this.$projectData.projectId, infoPlistFilePath);
            _this.replaceFileName("-Info.plist", path.join(projectRoot, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER)).wait();
            _this.replaceFileName("-Prefix.pch", path.join(projectRoot, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER)).wait();
            _this.replaceFileName(IOSProjectService.XCODE_PROJECT_EXT_NAME, projectRoot).wait();
            var pbxprojFilePath = path.join(projectRoot, _this.$projectData.projectName + IOSProjectService.XCODE_PROJECT_EXT_NAME, "project.pbxproj");
            _this.replaceFileContent(pbxprojFilePath).wait();
            var mainFilePath = path.join(projectRoot, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER, "main.m");
            _this.replaceFileContent(mainFilePath).wait();
        }).future()();
    };
    IOSProjectService.prototype.afterCreateProject = function (projectRoot) {
        var _this = this;
        return (function () {
            _this.$fs.rename(path.join(projectRoot, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER), path.join(projectRoot, _this.$projectData.projectName)).wait();
        }).future()();
    };
    IOSProjectService.prototype.buildProject = function (projectRoot) {
        var _this = this;
        return (function () {
            var basicArgs = [
                "-configuration", _this.$options.release ? "Release" : "Debug",
                "build",
                'SHARED_PRECOMPS_DIR=' + path.join(projectRoot, 'build', 'sharedpch')
            ];
            var xcworkspacePath = path.join(projectRoot, _this.$projectData.projectName + ".xcworkspace");
            if (_this.$fs.exists(xcworkspacePath).wait()) {
                basicArgs.push("-workspace", xcworkspacePath);
                basicArgs.push("-scheme", _this.$projectData.projectName);
            }
            else {
                basicArgs.push("-project", path.join(projectRoot, _this.$projectData.projectName + ".xcodeproj"));
                basicArgs.push("-target", _this.$projectData.projectName);
            }
            var args = [];
            if (_this.$options.forDevice) {
                args = basicArgs.concat([
                    "-xcconfig", path.join(projectRoot, _this.$projectData.projectName, "build.xcconfig"),
                    "-sdk", "iphoneos",
                    'ARCHS=armv7 arm64',
                    'VALID_ARCHS=armv7 arm64',
                    "CONFIGURATION_BUILD_DIR=" + path.join(projectRoot, "build", "device")
                ]);
            }
            else {
                args = basicArgs.concat([
                    "-sdk", "iphonesimulator",
                    "-arch", "i386",
                    "VALID_ARCHS=\"i386\"",
                    "CONFIGURATION_BUILD_DIR=" + path.join(projectRoot, "build", "emulator")
                ]);
            }
            _this.$childProcess.spawnFromEvent("xcodebuild", args, "exit", { cwd: _this.$options, stdio: 'inherit' }).wait();
            if (_this.$options.forDevice) {
                var buildOutputPath = path.join(projectRoot, "build", "device");
                var xcrunArgs = [
                    "-sdk", "iphoneos",
                    "PackageApplication",
                    "-v", path.join(buildOutputPath, _this.$projectData.projectName + ".app"),
                    "-o", path.join(buildOutputPath, _this.$projectData.projectName + ".ipa")
                ];
                _this.$childProcess.spawnFromEvent("xcrun", xcrunArgs, "exit", { cwd: _this.$options, stdio: 'inherit' }).wait();
            }
        }).future()();
    };
    IOSProjectService.prototype.isPlatformPrepared = function (projectRoot) {
        return this.$fs.exists(path.join(projectRoot, this.$projectData.projectName, constants.APP_FOLDER_NAME));
    };
    IOSProjectService.prototype.addLibrary = function (libraryPath) {
        var _this = this;
        return (function () {
            _this.validateFramework(libraryPath).wait();
            var targetPath = path.join("lib", _this.platformData.normalizedPlatformName);
            var fullTargetPath = path.join(_this.$projectData.projectDir, targetPath);
            _this.$fs.ensureDirectoryExists(fullTargetPath).wait();
            shell.cp("-R", libraryPath, fullTargetPath);
            var project = _this.createPbxProj();
            var frameworkName = path.basename(libraryPath, path.extname(libraryPath));
            var frameworkBinaryPath = path.join(libraryPath, frameworkName);
            var isDynamic = _.contains(_this.$childProcess.exec("otool -Vh " + frameworkBinaryPath).wait(), " DYLIB ");
            var frameworkAddOptions = { customFramework: true };
            if (isDynamic) {
                frameworkAddOptions["embed"] = true;
                project.updateBuildProperty("IPHONEOS_DEPLOYMENT_TARGET", "8.0");
                _this.$logger.info("The iOS Deployment Target is now 8.0 in order to support Cocoa Touch Frameworks.");
            }
            var frameworkPath = _this.getFrameworkRelativePath(libraryPath);
            project.addFramework(frameworkPath, frameworkAddOptions);
            _this.savePbxProj(project).wait();
        }).future()();
    };
    IOSProjectService.prototype.canUpdatePlatform = function (currentVersion, newVersion) {
        var _this = this;
        return (function () {
            var currentXcodeProjectFile = _this.buildPathToXcodeProjectFile(currentVersion);
            var currentXcodeProjectFileContent = _this.$fs.readFile(currentXcodeProjectFile).wait();
            var newXcodeProjectFile = _this.buildPathToXcodeProjectFile(newVersion);
            var newXcodeProjectFileContent = _this.$fs.readFile(newXcodeProjectFile).wait();
            return currentXcodeProjectFileContent === newXcodeProjectFileContent;
        }).future()();
    };
    IOSProjectService.prototype.updatePlatform = function (currentVersion, newVersion, canUpdate) {
        var _this = this;
        return (function () {
            if (!canUpdate) {
                var isUpdateConfirmed = _this.$prompter.confirm("We need to override xcodeproj file. The old one will be saved at " + _this.$options.profileDir + ". Are you sure?", function () { return true; }).wait();
                if (isUpdateConfirmed) {
                    var sourceDir = path.join(_this.platformData.projectRoot, _this.$projectData.projectName + ".xcodeproj");
                    var destinationDir = path.join(_this.$options.profileDir, "xcodeproj");
                    _this.$fs.deleteDirectory(destinationDir).wait();
                    shell.cp("-R", path.join(sourceDir, "*"), destinationDir);
                    _this.$logger.info("Backup file " + sourceDir + " at location " + destinationDir);
                    _this.$fs.deleteDirectory(sourceDir).wait();
                    var cachedPackagePath = path.join(_this.$npmInstallationManager.getCachedPackagePath(_this.platformData.frameworkPackageName, newVersion), constants.PROJECT_FRAMEWORK_FOLDER_NAME, util.format("%s.xcodeproj", IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER));
                    shell.cp("-R", path.join(cachedPackagePath, "*"), sourceDir);
                    _this.$logger.info("Copied from " + cachedPackagePath + " at " + _this.platformData.projectRoot + ".");
                    var pbxprojFilePath = path.join(_this.platformData.projectRoot, _this.$projectData.projectName + IOSProjectService.XCODE_PROJECT_EXT_NAME, "project.pbxproj");
                    _this.replaceFileContent(pbxprojFilePath).wait();
                }
                return isUpdateConfirmed;
            }
            return true;
        }).future()();
    };
    IOSProjectService.prototype.prepareProject = function () {
        var _this = this;
        return (function () {
            var project = _this.createPbxProj();
            var resources = project.pbxGroupByName("Resources");
            if (resources) {
                var references = project.pbxFileReferenceSection();
                var xcodeProjectImages = _.map(resources.children, function (resource) { return _this.replace(references[resource.value].name); });
                _this.$logger.trace("Images from Xcode project");
                _this.$logger.trace(xcodeProjectImages);
                var appResourcesImages = _this.$fs.readDirectory(_this.getAppResourcesDestinationDirectoryPath().wait()).wait();
                _this.$logger.trace("Current images from App_Resources");
                _this.$logger.trace(appResourcesImages);
                var imagesToAdd = _.difference(appResourcesImages, xcodeProjectImages);
                _this.$logger.trace("New images to add into xcode project: " + imagesToAdd.join(", "));
                _.each(imagesToAdd, function (image) { return project.addResourceFile(path.relative(_this.platformData.projectRoot, path.join(_this.getAppResourcesDestinationDirectoryPath().wait(), image))); });
                var imagesToRemove = _.difference(xcodeProjectImages, appResourcesImages);
                _this.$logger.trace("Images to remove from xcode project: " + imagesToRemove.join(", "));
                _.each(imagesToRemove, function (image) { return project.removeResourceFile(path.join(_this.getAppResourcesDestinationDirectoryPath().wait(), image)); });
                _this.savePbxProj(project).wait();
            }
        }).future()();
    };
    IOSProjectService.prototype.prepareAppResources = function (appResourcesDirectoryPath) {
        var _this = this;
        return (function () {
            _this.$fs.deleteDirectory(_this.getAppResourcesDestinationDirectoryPath().wait()).wait();
        }).future()();
    };
    Object.defineProperty(IOSProjectService.prototype, "projectPodFilePath", {
        get: function () {
            return path.join(this.platformData.projectRoot, "Podfile");
        },
        enumerable: true,
        configurable: true
    });
    IOSProjectService.prototype.replace = function (name) {
        if (_.startsWith(name, '"')) {
            name = name.substr(1, name.length - 2);
        }
        return name.replace(/\\\"/g, "\"");
    };
    IOSProjectService.prototype.getFrameworkRelativePath = function (libraryPath) {
        var frameworkName = path.basename(libraryPath, path.extname(libraryPath));
        var targetPath = path.join("lib", this.platformData.normalizedPlatformName);
        var frameworkPath = path.relative("platforms/ios", path.join(targetPath, frameworkName + ".framework"));
        return frameworkPath;
    };
    Object.defineProperty(IOSProjectService.prototype, "pbxProjPath", {
        get: function () {
            return path.join(this.platformData.projectRoot, this.$projectData.projectName + ".xcodeproj", "project.pbxproj");
        },
        enumerable: true,
        configurable: true
    });
    IOSProjectService.prototype.createPbxProj = function () {
        var project = new xcode.project(this.pbxProjPath);
        project.parseSync();
        return project;
    };
    IOSProjectService.prototype.savePbxProj = function (project) {
        return this.$fs.writeFile(this.pbxProjPath, project.writeSync());
    };
    IOSProjectService.prototype.preparePluginNativeCode = function (pluginData, opts) {
        var _this = this;
        return (function () {
            var pluginPlatformsFolderPath = pluginData.pluginPlatformsFolderPath(IOSProjectService.IOS_PLATFORM_NAME);
            _this.prepareFrameworks(pluginPlatformsFolderPath, pluginData).wait();
            _this.prepareCocoapods(pluginPlatformsFolderPath, opts).wait();
        }).future()();
    };
    IOSProjectService.prototype.removePluginNativeCode = function (pluginData) {
        var _this = this;
        return (function () {
            var pluginPlatformsFolderPath = pluginData.pluginPlatformsFolderPath(IOSProjectService.IOS_PLATFORM_NAME);
            _this.removeFrameworks(pluginPlatformsFolderPath, pluginData).wait();
            _this.removeCocoapods(pluginPlatformsFolderPath).wait();
        }).future()();
    };
    IOSProjectService.prototype.afterPrepareAllPlugins = function () {
        var _this = this;
        return (function () {
            if (_this.$fs.exists(_this.projectPodFilePath).wait()) {
                try {
                    _this.$childProcess.exec("gem which cocoapods").wait();
                    _this.$childProcess.exec("gem which xcodeproj").wait();
                }
                catch (e) {
                    _this.$errors.failWithoutHelp("CocoaPods or ruby gem 'xcodeproj' is not installed. Run `sudo gem install cocoapods` and try again.");
                }
                var projectPodfileContent = _this.$fs.readText(_this.projectPodFilePath).wait();
                _this.$logger.trace("Project Podfile content");
                _this.$logger.trace(projectPodfileContent);
                var firstPostInstallIndex = projectPodfileContent.indexOf(IOSProjectService.PODFILE_POST_INSTALL_SECTION_NAME);
                if (firstPostInstallIndex !== -1 && firstPostInstallIndex !== projectPodfileContent.lastIndexOf(IOSProjectService.PODFILE_POST_INSTALL_SECTION_NAME)) {
                    _this.$logger.warn("Podfile contains more than one post_install sections. You need to open " + _this.projectPodFilePath + " file and manually resolve this issue.");
                }
                var pbxprojFilePath = path.join(_this.platformData.projectRoot, _this.$projectData.projectName + IOSProjectService.XCODE_PROJECT_EXT_NAME, "xcuserdata");
                if (!_this.$fs.exists(pbxprojFilePath).wait()) {
                    _this.$logger.info("Creating project scheme...");
                    var createSchemeRubyScript = "ruby -e \"require 'xcodeproj'; xcproj = Xcodeproj::Project.open('" + _this.$projectData.projectName + ".xcodeproj'); xcproj.recreate_user_schemes; xcproj.save\"";
                    _this.$childProcess.exec(createSchemeRubyScript, { cwd: _this.platformData.projectRoot }).wait();
                }
                _this.executePodInstall().wait();
            }
        }).future()();
    };
    IOSProjectService.prototype.getAllFrameworksForPlugin = function (pluginData) {
        var filterCallback = function (fileName, pluginPlatformsFolderPath) { return path.extname(fileName) === ".framework"; };
        return this.getAllNativeLibrariesForPlugin(pluginData, IOSProjectService.IOS_PLATFORM_NAME, filterCallback);
    };
    IOSProjectService.prototype.buildPathToXcodeProjectFile = function (version) {
        return path.join(this.$npmInstallationManager.getCachedPackagePath(this.platformData.frameworkPackageName, version), constants.PROJECT_FRAMEWORK_FOLDER_NAME, util.format("%s.xcodeproj", IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER), "project.pbxproj");
    };
    IOSProjectService.prototype.validateFramework = function (libraryPath) {
        var _this = this;
        return (function () {
            var infoPlistPath = path.join(libraryPath, "Info.plist");
            if (!_this.$fs.exists(infoPlistPath).wait()) {
                _this.$errors.failWithoutHelp("The bundle at %s does not contain an Info.plist file.", libraryPath);
            }
            var packageType = _this.$childProcess.exec("/usr/libexec/PlistBuddy -c \"Print :CFBundlePackageType\" \"" + infoPlistPath + "\"").wait().trim();
            if (packageType !== "FMWK") {
                _this.$errors.failWithoutHelp("The bundle at %s does not appear to be a dynamic framework.", libraryPath);
            }
        }).future()();
    };
    IOSProjectService.prototype.replaceFileContent = function (file) {
        var _this = this;
        return (function () {
            var fileContent = _this.$fs.readText(file).wait();
            var replacedContent = helpers.stringReplaceAll(fileContent, IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER, _this.$projectData.projectName);
            _this.$fs.writeFile(file, replacedContent).wait();
        }).future()();
    };
    IOSProjectService.prototype.replaceFileName = function (fileNamePart, fileRootLocation) {
        var _this = this;
        return (function () {
            var oldFileName = IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER + fileNamePart;
            var newFileName = _this.$projectData.projectName + fileNamePart;
            _this.$fs.rename(path.join(fileRootLocation, oldFileName), path.join(fileRootLocation, newFileName)).wait();
        }).future()();
    };
    IOSProjectService.prototype.executePodInstall = function () {
        this.$logger.info("Installing pods...");
        return this.$childProcess.exec("pod install", { cwd: this.platformData.projectRoot });
    };
    IOSProjectService.prototype.prepareFrameworks = function (pluginPlatformsFolderPath, pluginData) {
        var _this = this;
        return (function () {
            _.each(_this.getAllFrameworksForPlugin(pluginData).wait(), function (fileName) { return _this.addLibrary(path.join(pluginPlatformsFolderPath, fileName)).wait(); });
        }).future()();
    };
    IOSProjectService.prototype.prepareCocoapods = function (pluginPlatformsFolderPath, opts) {
        var _this = this;
        return (function () {
            var pluginPodFilePath = path.join(pluginPlatformsFolderPath, "Podfile");
            if (_this.$fs.exists(pluginPodFilePath).wait()) {
                if (!_this.$fs.exists(_this.projectPodFilePath).wait()) {
                    _this.$fs.writeFile(_this.projectPodFilePath, "use_frameworks!\n").wait();
                }
                var pluginPodFileContent = _this.$fs.readText(pluginPodFilePath).wait();
                var contentToWrite = _this.buildPodfileContent(pluginPodFilePath, pluginPodFileContent);
                _this.$fs.appendFile(_this.projectPodFilePath, contentToWrite).wait();
            }
            if (opts && opts.executePodInstall && _this.$fs.exists(pluginPodFilePath).wait()) {
                _this.executePodInstall().wait();
            }
        }).future()();
    };
    IOSProjectService.prototype.removeFrameworks = function (pluginPlatformsFolderPath, pluginData) {
        var _this = this;
        return (function () {
            var project = _this.createPbxProj();
            _.each(_this.getAllFrameworksForPlugin(pluginData).wait(), function (fileName) {
                var fullFrameworkPath = path.join(pluginPlatformsFolderPath, fileName);
                var relativeFrameworkPath = _this.getFrameworkRelativePath(fullFrameworkPath);
                project.removeFramework(relativeFrameworkPath, { customFramework: true, embed: true });
            });
            _this.savePbxProj(project).wait();
        }).future()();
    };
    IOSProjectService.prototype.removeCocoapods = function (pluginPlatformsFolderPath) {
        var _this = this;
        return (function () {
            var pluginPodFilePath = path.join(pluginPlatformsFolderPath, "Podfile");
            if (_this.$fs.exists(pluginPodFilePath).wait()) {
                var pluginPodFileContent = _this.$fs.readText(pluginPodFilePath).wait();
                var projectPodFileContent = _this.$fs.readText(_this.projectPodFilePath).wait();
                var contentToRemove = _this.buildPodfileContent(pluginPodFilePath, pluginPodFileContent);
                projectPodFileContent = helpers.stringReplaceAll(projectPodFileContent, contentToRemove, "");
                if (projectPodFileContent.trim() === "use_frameworks!") {
                    _this.$fs.deleteFile(_this.projectPodFilePath).wait();
                }
                else {
                    _this.$fs.writeFile(_this.projectPodFilePath, projectPodFileContent).wait();
                }
            }
        }).future()();
    };
    IOSProjectService.prototype.buildPodfileContent = function (pluginPodFilePath, pluginPodFileContent) {
        return "# Begin Podfile - " + pluginPodFilePath + " " + os.EOL + " " + pluginPodFileContent + " " + os.EOL + " # End Podfile " + os.EOL;
    };
    IOSProjectService.XCODE_PROJECT_EXT_NAME = ".xcodeproj";
    IOSProjectService.XCODEBUILD_MIN_VERSION = "6.0";
    IOSProjectService.IOS_PROJECT_NAME_PLACEHOLDER = "__PROJECT_NAME__";
    IOSProjectService.IOS_PLATFORM_NAME = "ios";
    IOSProjectService.PODFILE_POST_INSTALL_SECTION_NAME = "post_install";
    return IOSProjectService;
})(projectServiceBaseLib.PlatformProjectServiceBase);
exports.IOSProjectService = IOSProjectService;
$injector.register("iOSProjectService", IOSProjectService);
