///<reference path="../../.d.ts"/>
"use strict";
var path = require("path");
var Future = require("fibers/future");
var destCopyLib = require("./node-modules-dest-copy");
var gulp = require("gulp");
var vinylFilterSince = require("vinyl-filter-since");
var through = require("through2");
var Builder = (function () {
    function Builder($fs, $nodeModulesTree, $projectDataService, $injector, $logger) {
        this.$fs = $fs;
        this.$nodeModulesTree = $nodeModulesTree;
        this.$projectDataService = $projectDataService;
        this.$injector = $injector;
        this.$logger = $logger;
        this.nodeModules = {};
    }
    Builder.prototype.prepareNodeModules = function (absoluteOutputPath, projectDir, platform, lastModifiedTime) {
        var _this = this;
        return (function () {
            var isNodeModulesModified = false;
            var nodeModulesPath = path.join(projectDir, "node_modules");
            if (lastModifiedTime) {
                var pipeline = gulp.src(path.join(projectDir, "node_modules/**"))
                    .pipe(vinylFilterSince(lastModifiedTime))
                    .pipe(through.obj(function (chunk, enc, cb) {
                    if (chunk.path === nodeModulesPath) {
                        isNodeModulesModified = true;
                    }
                    if (!isNodeModulesModified) {
                        var rootModuleName = chunk.path.split(nodeModulesPath)[1].split(path.sep)[1];
                        var rootModuleFullPath = path.join(nodeModulesPath, rootModuleName);
                        _this.nodeModules[rootModuleFullPath] = rootModuleFullPath;
                    }
                    cb(null);
                }))
                    .pipe(gulp.dest(absoluteOutputPath));
                var future = new Future();
                pipeline.on('end', function (err, data) {
                    if (err) {
                        future.throw(err);
                    }
                    else {
                        future.return();
                    }
                });
                future.wait();
            }
            if (isNodeModulesModified && _this.$fs.exists(absoluteOutputPath).wait()) {
                var currentPreparedTnsModules = _this.$fs.readDirectory(absoluteOutputPath).wait();
                var tnsModulesPath = path.join(projectDir, "app", "tns_modules");
                if (!_this.$fs.exists(tnsModulesPath).wait()) {
                    tnsModulesPath = path.join(projectDir, "node_modules", "tns-core-modules");
                }
                var tnsModulesInApp = _this.$fs.readDirectory(tnsModulesPath).wait();
                var modulesToDelete = _.difference(currentPreparedTnsModules, tnsModulesInApp);
                _.each(modulesToDelete, function (moduleName) { return _this.$fs.deleteDirectory(path.join(absoluteOutputPath, moduleName)).wait(); });
            }
            if (!lastModifiedTime || isNodeModulesModified) {
                var nodeModulesDirectories = _this.$fs.exists(nodeModulesPath).wait() ? _this.$fs.readDirectory(nodeModulesPath).wait() : [];
                _.each(nodeModulesDirectories, function (nodeModuleDirectoryName) {
                    var nodeModuleFullPath = path.join(nodeModulesPath, nodeModuleDirectoryName);
                    _this.nodeModules[nodeModuleFullPath] = nodeModuleFullPath;
                });
            }
            var destCopy = _this.$injector.resolve(destCopyLib.DestCopy, {
                inputPath: projectDir,
                cachePath: "",
                outputRoot: absoluteOutputPath,
                projectDir: projectDir,
                platform: platform
            });
            destCopy.rebuildChangedDirectories(_.keys(_this.nodeModules));
        }).future()();
    };
    return Builder;
})();
exports.Builder = Builder;
$injector.register("broccoliBuilder", Builder);
